@@ -1,7 +1,10 @@
 
 from typing import Union
+from textwrap import dedent
 from redmail import EmailSender
 
+from convert import remove_email_content_id
+
 def test_distributions():
     class DistrSender(EmailSender):
         "Send email using pre-defined distribution lists"
@@ -37,9 +40,10 @@ def test_distributions():
         cc="group2",
         subject="Some email",
     )
-    assert dict(msg.items()) == {
-        'from': 'me@example.com', 
-        'subject': 'Some email', 
-        'to': 'me@example.com, you@example.com', 
-        'cc': 'he@example.com, she@example.com', 
-    }
\ No newline at end of file
+    assert remove_email_content_id(str(msg)) == dedent("""
+    from: me@example.com
+    subject: Some email
+    to: me@example.com, you@example.com
+    cc: he@example.com, she@example.com
+
+    """)[1:]
\ No newline at end of file
